@@ -221,10 +221,14 @@ async def run_oauth_flow(client_id: str, client_secret: str, is_production: bool
         # Set up environment variables BEFORE database initialization
         os.environ['TASTYTRADE_USE_PRODUCTION'] = 'true' if is_production else 'false'
         os.environ['TASTYTRADE_USE_DATABASE_MODE'] = 'true'
-        os.environ['OAUTH_CLIENT_ID'] = client_id
-        os.environ['OAUTH_CLIENT_SECRET'] = client_secret
+        os.environ['TASTYTRADE_CLIENT_ID'] = client_id
+        os.environ['TASTYTRADE_CLIENT_SECRET'] = client_secret
         os.environ['DATABASE_URL'] = 'sqlite+aiosqlite:///./tastytrade_mcp.db'
 
+        # Force reload settings to pick up new environment variables
+        from tastytrade_mcp.config import settings as settings_module
+        settings_module._settings = None  # Clear cached settings
+
         # Initialize database if needed (create tables)
         try:
             await init_db()
@@ -413,25 +417,27 @@ def setup(
             console.print(f"\n[green]✓ Created configuration file: {env_path}[/green]")
 
         elif mode == "database":
-            # Database mode setup
+            # Database mode setup with personal grant
             if interactive:
-                console.print("\n[blue]Database Mode: OAuth2 Setup[/blue]")
-                console.print("[yellow]You'll need OAuth2 credentials from TastyTrade Developer Portal[/yellow]")
+                console.print("\n[blue]Database Mode: OAuth2 Personal Grant Setup[/blue]")
+                console.print("[yellow]Follow these steps to get your OAuth credentials:[/yellow]\n")
+                console.print("1. Go to: https://my.tastytrade.com")
+                console.print("2. Navigate to: Manage → My Profile → API → OAuth Applications")
+                console.print("3. Click '+ New OAuth Client' and fill out:")
+                console.print("   - Redirect URI: http://localhost:8000/callback")
+                console.print("   - Scopes: read, trade")
+                console.print("4. Copy your Client ID and Client Secret")
+                console.print("5. Click 'Manage' → 'Create Grant' to get your Refresh Token\n")
 
                 client_id = Prompt.ask("[yellow]OAuth2 Client ID")
                 client_secret = Prompt.ask("[yellow]OAuth2 Client Secret", password=True)
+                refresh_token = Prompt.ask("[yellow]Refresh Token (from personal grant)", password=True)
             else:
                 client_id = os.getenv("TASTYTRADE_CLIENT_ID")
                 client_secret = os.getenv("TASTYTRADE_CLIENT_SECRET")
-                if not client_id or not client_secret:
-                    raise SetupError("OAuth2 credentials required for database mode")
-
-            # Run OAuth flow
-            console.print("\n[blue]Starting OAuth2 authorization flow...[/blue]")
-            refresh_token = asyncio.run(run_oauth_flow(client_id, client_secret, use_production))
-
-            if not refresh_token:
-                raise SetupError("Failed to get OAuth2 refresh token")
+                refresh_token = os.getenv("TASTYTRADE_REFRESH_TOKEN")
+                if not client_id or not client_secret or not refresh_token:
+                    raise SetupError("OAuth2 credentials and refresh token required for database mode")
 
             # Create .env file
             env_path = create_env_file(
